exceptiontools.TieChainError
============================

.. abjad-lineage:: abjad.tools.exceptiontools.TieChainError.TieChainError

.. autoclass:: abjad.tools.exceptiontools.TieChainError.TieChainError
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.TieChainError.TieChainError.__delattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TieChainError.TieChainError.__getitem__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TieChainError.TieChainError.__getslice__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TieChainError.TieChainError.__repr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TieChainError.TieChainError.__setattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TieChainError.TieChainError.__setstate__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TieChainError.TieChainError.__str__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.TieChainError.TieChainError.__unicode__
   :noindex:
